@@ -34,7 +34,7 @@ class K9Core:
         if r.ok:
             try:
                 result = r.json()
-                return K9CoreResponse(**result)
+                #return K9CoreResponse(**result)
             except (JSONDecodeError, AttributeError) as error:
                 logging.error("Invalid payload: ", r.text)
                 return K9CoreError(message=message,status_code=r.status_code,payload=message)
